[Libreoffice-commits] core.git: include/svx vcl/source vcl/unx

Andrea Gelmini (via logerrit) logerrit at kemper.freedesktop.org
Sun Jun 14 07:21:46 UTC 2020


 include/svx/signaturelinehelper.hxx |    2 +-
 vcl/source/app/salvtables.cxx       |    2 +-
 vcl/unx/gtk3/gtk3gtkinst.cxx        |    4 ++--
 3 files changed, 4 insertions(+), 4 deletions(-)

New commits:
commit ef08ba8f89c4a2ff911a82498993ef88b40f2b92
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Tue Jun 9 19:15:18 2020 +0200
Commit:     Julien Nabet <serval2412 at yahoo.fr>
CommitDate: Sun Jun 14 09:21:13 2020 +0200

    Fix typos
    
    Change-Id: Ibe78c7164c989b7010ee96bbbd728218c58daad9
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/95961
    Tested-by: Jenkins
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>

diff --git a/include/svx/signaturelinehelper.hxx b/include/svx/signaturelinehelper.hxx
index 0906d88ef095..70ddbfbf7905 100644
--- a/include/svx/signaturelinehelper.hxx
+++ b/include/svx/signaturelinehelper.hxx
@@ -50,7 +50,7 @@ getSignerName(const css::uno::Reference<css::security::XCertificate>& xCertifica
 SVX_DLLPUBLIC OUString getLocalizedDate();
 
 /**
- * Interprets rSVG as a graphic and gives back the resuling UNO wrapper.
+ * Interprets rSVG as a graphic and gives back the resulting UNO wrapper.
  */
 SVX_DLLPUBLIC css::uno::Reference<css::graphic::XGraphic> importSVG(const OUString& rSVG);
 
diff --git a/vcl/source/app/salvtables.cxx b/vcl/source/app/salvtables.cxx
index 9b34a5cbfa32..222def7b8bdf 100644
--- a/vcl/source/app/salvtables.cxx
+++ b/vcl/source/app/salvtables.cxx
@@ -3200,7 +3200,7 @@ private:
     DECL_LINK(CustomMeasureHdl, svtree_measure_args, Size);
 
     // Each row has a cell for the expander image, (and an optional cell for a
-    // checkbutton if enable_toggle_buttons has been called) which preceed
+    // checkbutton if enable_toggle_buttons has been called) which precede
     // index 0
     int to_internal_model(int col) const
     {
diff --git a/vcl/unx/gtk3/gtk3gtkinst.cxx b/vcl/unx/gtk3/gtk3gtkinst.cxx
index 058bdfb38e4c..f394a04fba84 100644
--- a/vcl/unx/gtk3/gtk3gtkinst.cxx
+++ b/vcl/unx/gtk3/gtk3gtkinst.cxx
@@ -9544,7 +9544,7 @@ private:
     // The outside concept of a column maps to a gtk CellRenderer, rather than
     // a TreeViewColumn. If the first TreeViewColumn has a leading Toggle Renderer
     // and/or a leading Image Renderer, those are considered special expander
     // columns and preceed index 0 and can be accessed via outside index -1
     int to_external_model(int modelcol) const
     {
         if (m_nExpanderToggleCol != -1)
@@ -9815,7 +9815,7 @@ public:
         /* The outside concept of a column maps to a gtk CellRenderer, rather than
            a TreeViewColumn. If the first TreeViewColumn has a leading Toggle Renderer
            and/or a leading Image Renderer, those are considered special expander
-           columns and preceed index 0 and can be accessed via outside index -1
+           columns and precede index 0 and can be accessed via outside index -1
         */
         m_pColumns = gtk_tree_view_get_columns(m_pTreeView);
         int nIndex(0);
@@ -9544,7 +9544,7 @@ private:
     // a TreeViewColumn. If the first TreeViewColumn has a leading Toggle Renderer
     // and/or a leading Image Renderer, those are considered special expander
-    // columns and preceed index 0 and can be accessed via outside index -1
+    // columns and precede index 0 and can be accessed via outside index -1
     int to_external_model(int modelcol) const
     {


More information about the Libreoffice-commits mailing list